@@ -18,6 +18,7 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """List Command Module."""
+
 from __future__ import annotations
 
 import logging
@@ -79,11 +80,12 @@ def list_(
 ) -> None:  # pragma: no cover
     """List status of instances.
 
+    \f
     Args:
         ctx: Click context object holding commandline arguments.
         scenario_name: Name of the scenario to target.
         format: Output format type.
-    """
+    """  # noqa: D301
     args: MoleculeArgs = ctx.obj.get("args")
     subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args: CommandArgs = {"subcommand": subcommand, "format": format}
@@ -91,7 +93,7 @@ def list_(
     statuses = []
     s = scenarios.Scenarios(
         base.get_configs(args, command_args, glob_str=MOLECULE_GLOB),
-        scenario_name,
+        None if scenario_name is None else [scenario_name],
     )
     for scenario in s:
         statuses.extend(base.execute_subcommand(scenario.config, subcommand))
@@ -142,7 +144,13 @@ def _print_yaml_data(
         data: A list of tabular data to display.
     """
     l = [  # noqa: E741
-        dict(zip(headers, [getattr(datum, field) for field in datum._fields], strict=False))
+        dict(
+            zip(
+                headers,
+                [getattr(datum, field) for field in datum._fields],
+                strict=False,
+            ),
+        )
         for datum in data
     ]
 
