@@ -60,19 +60,26 @@ def verify(
     *,
     __all: bool,
     report: bool,
+    shared_inventory: bool,
 ) -> None:  # pragma: no cover
     """Run automated tests against instances.
 
+    \f
     Args:
         ctx: Click context object holding commandline arguments.
         scenario_name: Name of the scenario to target.
         exclude: Name of the scenarios to avoid targeting.
         __all: Whether molecule should target scenario_name or all scenarios.
         report: Whether to show an after-run summary report.
-    """
+        shared_inventory: Whether the inventory should be shared between scenarios.
+    """  # noqa: D301
     args: MoleculeArgs = ctx.obj.get("args")
     subcommand = base._get_subcommand(__name__)  # noqa: SLF001
-    command_args: CommandArgs = {"subcommand": subcommand, "report": report}
+    command_args: CommandArgs = {
+        "subcommand": subcommand,
+        "report": report,
+        "shared_inventory": shared_inventory,
+    }
 
     if __all:
         scenario_name = None
