@@ -18,13 +18,21 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 """PLatforms Module."""
+
 from __future__ import annotations
 
 import logging
 
+from typing import TYPE_CHECKING
+
 from molecule import util
 
 
+if TYPE_CHECKING:
+    from molecule.config import Config
+    from molecule.types import PlatformData
+
+
 LOG = logging.getLogger(__name__)
 
 
@@ -69,7 +77,12 @@ class Platforms:
     ```
     """
 
-    def __init__(self, config, parallelize_platforms=False, platform_name=None) -> None:  # type: ignore[no-untyped-def]  # noqa: ANN001, FBT002
+    def __init__(
+        self,
+        config: Config,
+        parallelize_platforms: bool = False,  # noqa: FBT001, FBT002
+        platform_name: str | None = None,
+    ) -> None:
         """Initialize a new platform class and returns None.
 
         Args:
@@ -78,17 +91,22 @@ class Platforms:
             platform_name: One platform to target only, defaults to None.
         """
         if platform_name:
-            config.config["platforms"] = util._filter_platforms(  # type: ignore[no-untyped-call]  # noqa: SLF001
+            config.config["platforms"] = util._filter_platforms(  # noqa: SLF001
                 config.config,
                 platform_name,
             )
         if parallelize_platforms:
-            config.config["platforms"] = util._parallelize_platforms(  # type: ignore[no-untyped-call]  # noqa: SLF001
+            config.config["platforms"] = util._parallelize_platforms(  # noqa: SLF001
                 config.config,
                 config._run_uuid,  # noqa: SLF001
             )
         self._config = config
 
     @property
-    def instances(self):  # type: ignore[no-untyped-def]  # noqa: ANN201, D102
+    def instances(self) -> list[PlatformData]:
+        """The platforms defined in the config.
+
+        Returns:
+            The list of platforms in the config.
+        """
         return self._config.config["platforms"]
